# This migration tool converts OSQA data to Askbot, optimized for big databases
# Copyright (C) 2016  Pietro Albini <pietroalbini@ubuntu.com>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or (at
# your option) any later version.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from __future__ import absolute_import
from __future__ import print_function

import os
import sys
import site
import pkg_resources


def load_django(path, env):
    # Load the app's virtualenv
    site_packages = os.path.join(
        env, 'lib', 'python%s' % sys.version[:3], 'site-packages'
    )
    site.addsitedir(site_packages)

    # Switch to the app's directory
    app_path = os.path.abspath(os.path.expanduser(path))
    sys.path.append(app_path)
    os.chdir(app_path)

    # Refresh pkg_resources working set to discover new modules
    pkg_resources.working_set = pkg_resources.WorkingSet()

    # Tell Django where to find settings
    os.environ["DJANGO_SETTINGS_MODULE"] = "settings"

    # Load django
    import django
    django.setup()

    return django


def load_models():
    import askbot
    return askbot.models


def load_openid_models():
    import askbot.deps.django_authopenid
    return askbot.deps.django_authopenid.models
